==> moodle-1.4.3-pgsql.tgz: moodle/lang/sv/forum.php <==
<?PHP // $Id$ 
      // forum.php - created with Moodle 1.4 (2004083100)


$string['addanewdiscussion'] = 'Lgg till ett nytt diskussionsmne';
$string['addanewtopic'] = 'Lgg till ett nytt mne';
$string['allowchoice'] = 'Tillt alla att vlja';
$string['allowdiscussions'] = 'Kan en $a gra inlgg i detta forum?';
$string['allowratings'] = 'Vill Du att det ska vara tilltet att bedma/vrdera inlgg?';
$string['allowsdiscussions'] = 'Detta forum tillter var och en att starta ett diskussionsmne.';
$string['anyfile'] = 'Vilken fil som helst';
$string['attachment'] = 'Bilaga';
$string['bynameondate'] = 'av $a->name - $a->date';
$string['configdisplaymode'] = 'Det frinstllda sttet att visa diskussionsmnen, om Du inte har stllt in ett annat.';
$string['configenablerssfeeds'] = 'Den hr omkopplaren aktiverar RSS -inmatning fr alla forum. Du mste dock fortfarande koppla p inmatningen manuellt i instlllningarna fr varje enskilt forum.';
$string['configlongpost'] = 'Alla inlgg som verskrider den hr lngden (frutom HTML) anses vara lnga.';
$string['configmanydiscussions'] = 'Maximalt antal diskussionsmnen som visas per sida i ett forum.';
$string['configmaxbytes'] = 'Standardval (frinstllt vrde) fr den maximala storleken p bifogade filer p den hr webbsajten (det finns ven lokala instllningar fr t ex varje enskild kurs)';
$string['configreplytouser'] = 'Nr ett inlgg i ett forum har skickats som e-post; ska det d innehlla anvndarens e-postadress s att mottagarna kan svara personligen snarare n via forumet? ven om Du vljer \"Ja\" fr denna instllning s kan anvndaren i sin profil vlja att dlja sin e-postadress.';
$string['configshortpost'] = 'Alla inlgg som verskrider den hr lngden (frutom HTML) anses vara lnga.';
$string['couldnotadd'] = 'Det gick inte att lgga till Ditt inlgg p grund av oknt fel.';
$string['couldnotdeleteratings'] = 'Tyvrr, detta kan inte tas bort eftersom folk redan har vrderat det.';
$string['couldnotdeletereplies'] = 'Tyvrr, det kan inte tas bort eftersom folk redan har svarat p det.';
$string['couldnotupdate'] = 'Det gick inte att uppdatera Ditt inlgg p grund av oknt fel.';
$string['delete'] = 'Ta bort';
$string['deleteddiscussion'] = 'Diskussionsmnet har tagits bort';
$string['deletedpost'] = 'Inlgget har tagits bort';
$string['deletesure'] = 'r Du sker p att Du vill ta bort detta inlgg?';
$string['digestmailheader'] = 'Det hr r Din dagliga sammanfattning av nya inlgg  i $a->sitename forum. Fr att ndra p Dina val a e-post frn forum - g till $a->userprefs ';
$string['digestmailprefs'] = 'Din anvndarprofil';
$string['digestmailsubject'] = '$a: sammanfattning av forum';
$string['digestsentusers'] = 'Sammanfattande e-postmeddelanden har skickats till $a anvndare.';
$string['discussion'] = 'Diskussionsmne';
$string['discussionmoved'] = 'Den hr diskussionsmnet har flyttats till \'$a\'.';
$string['discussionname'] = 'Namn p diskussion';
$string['discussions'] = 'Diskussionsmnen';
$string['discussionsstartedby'] = '$a  inledde det hr diskussionsmnet';
$string['discussionsstartedbyrecent'] = 'Diskussioner som nyligen har inletts av \'$a\'.';
$string['discussthistopic'] = 'Diskutera detta mne';
$string['eachuserforum'] = 'Var och en  bidrar med ett  diskussionsmne';
$string['edit'] = 'Redigera';
$string['editing'] = 'Redigering';
$string['emptymessage'] = 'Ngot var fel med Ditt inlgg.  Kanske skrev Du inte in ngon text, eller s var bilagan fr stor.  Dina ndringar har INTE sparats.';
$string['everyonecanchoose'] = 'Alla kan vlja att prenumerera';
$string['everyoneissubscribed'] = 'Alla prenumererar p detta forum';
$string['existingsubscribers'] = 'Befintliga prenumeranter';
$string['forcesubscribe'] = 'Tvinga alla att prenumerera';
$string['forcesubscribeq'] = 'Tvinga alla att prenumerera?';
$string['forum'] = 'Forum';
$string['forumintro'] = 'Introduktion till forum';
$string['forumname'] = 'Forumets namn';
$string['forums'] = 'Forum';
$string['forumtype'] = 'Typ av forum';
$string['generalforum'] = 'Standardforum fr allmnt bruk';
$string['generalforums'] = 'Allmnna forum';
$string['inforum'] = 'i $a';
$string['intronews'] = 'Allmnna nyheter och meddelanden';
$string['introsocial'] = 'Ett ppet forum dr Du kan diskutera vad Du vill';
$string['introteacher'] = 'Ett forum endast fr distanslrares anteckningar och diskussionsmnen';
$string['lastpost'] = 'Senaste inlgg';
$string['learningforums'] = 'Forum fr lrande';
$string['maxattachmentsize'] = 'Maximal storlek p bifogad fil';
$string['maxtimehaspassed'] = 'Tyvrr, men maximitiden fr att redigera detta inlgg ($a) har passerat!';
$string['message'] = 'Meddelande';
$string['modeflatnewestfirst'] = 'Visa svarslista, med det senaste frst';
$string['modeflatoldestfirst'] = 'Visa svarslista, med det ldsta frst';
$string['modenested'] = 'Visa svar i nstlad form';
$string['modethreaded'] = 'Visa svar i trdad form';
$string['modulename'] = 'Forum';
$string['modulenameplural'] = 'Forum';
$string['more'] = 'mer';
$string['movethisdiscussionto'] = 'Flytta det hr diskussionsmnet  till...';
$string['namenews'] = 'Nyhetsforum';
$string['namesocial'] = 'Gemenskapsforum';
$string['nameteacher'] = 'Lrarforum';
$string['newforumposts'] = 'Nya inlgg i forum';
$string['nodiscussions'] = 'Det finns nnu inga diskussionsmnen i detta forum';
$string['noguestpost'] = 'Tyvrr, gster har ingen behrighet att gra inlgg hr';
$string['nomorepostscontaining'] = 'Det gick inte att hitta ngra inlgg som innehller \'$a\' ';
$string['nonews'] = 'Inga nya inlgg nnu';
$string['noposts'] = 'Inga inlgg';
$string['nopostscontaining'] = 'Det gick inte att hitta  ngra inlgg som innehller \'$a\' ';
$string['nosubscribers'] = 'Det finns nnu inga prenumeranter p detta forum';
$string['notingroup'] = 'Du mste tyvrr vara med i en grupp fr att se detta forum.';
$string['nownotsubscribed'] = '$a->name kommmer INTE f kopior av \'$a->forum\' med e-post.';
$string['nowsubscribed'] = '$a->name kommer f kopior av \'$a->forum\' med e-post.';
$string['numposts'] = '$a inlgg';
$string['olderdiscussions'] = 'ldre diskussionsmnen';
$string['openmode0'] = 'Inga diskussionsmnen, inga svar';
$string['openmode1'] = 'Inga diskussionsmnen, men svar r tilltna';
$string['openmode2'] = 'Diskussionsmnen och svar r tilltna';
$string['parent'] = 'Visa \'frldern\' till detta inlgg';
$string['parentofthispost'] = 'Frldern till detta inlgg';
$string['postadded'] = 'Ditt inlgg har lagts till.<p>Du har $a fr att redigera det om Du vill gra ndringar.';
$string['postincontext'] = 'Se detta inlgg i sitt sammanhang';
$string['postmailinfo'] = 'Detta r en kopia p ett meddelande inlagt p $a webbplats.
Fr att lgga till Ditt svar via webbplatsen, klicka p denna lnk:';
$string['postrating1'] = 'Visar mest enskilt,(rationellt) inriktat  vetande (kunskap)';
$string['postrating2'] = 'Enskilt,(rationellt) inriktat  vetande (kunskap) och socialt, (empatiskt) inriktat vetande (kunskap)';
$string['postrating3'] = 'Visar mest socialt, (empatiskt) inriktat vetande (kunskap)';
$string['posts'] = 'Inlgg';
$string['posttoforum'] = 'Publicera inlgget i forumet';
$string['postupdated'] = 'Ditt inlgg har blivit uppdaterat';
$string['potentialsubscribers'] = 'Mjliga prenumeranter';
$string['processingdigest'] = 'Bearbetar sammanfattande e-postmeddelande fr anvndare $a';
$string['processingpost'] = 'Bearbetar inlgg $a';
$string['prune'] = 'Avbryt';
$string['prunedpost'] = 'Ett nytt diskussionsmne har skapats av posten';
$string['pruneheading'] = 'Avbryt inlgg och flytta till ett nytt diskussionsmne';
$string['rate'] = 'Omdme';
$string['rating'] = 'Bedmning/vrdering';
$string['ratingeveryone'] = 'Alla kan bedma/vrdera ett inlgg';
$string['ratingno'] = 'Ingen bedmning/vrdering';
$string['ratingonlyteachers'] = 'Endast $a kan bedma/vrdera inlgg';
$string['ratingpublic'] = '$a kan se allas bedmningar/vrderingar';
$string['ratingpublicnot'] = '$a kan bara se sina egna bedmningar/vrderingar';
$string['ratings'] = 'Bedmning/vrdering';
$string['ratingssaved'] = 'bedmningarna/vrderingarna har blivit  sparade';
$string['ratingsuse'] = 'Anvnd bedmningar/vrderingar ';
$string['ratingtime'] = 'Begrnsa bedmning/vrdering till inlgg med datum i det hr intervallet:';
$string['re'] = 'Svar:';
$string['readtherest'] = 'Ls fortsttningen p detta mne';
$string['replies'] = 'Svar:';
$string['repliesmany'] = '$a svar s lngt';
$string['repliesone'] = '$a svar s lngt';
$string['reply'] = 'Svar';
$string['replyforum'] = 'Svar till forum';
$string['rsssubscriberssdiscussions'] = 'Visa RSS-inmatningen fr  \'$a\' diskussionsmnen';
$string['rsssubscriberssposts'] = 'Visa RSS-inmatningen fr  \'$a\'  inlgg';
$string['search'] = 'Sk';
$string['searchforums'] = 'Sk forum';
$string['searcholderposts'] = 'Sk ldre inlgg...';
$string['searchresults'] = 'Skresultat';
$string['sendinratings'] = 'Snd in mina senaste bedmningar/vrderingar';
$string['showsubscribers'] = 'Visa prenumeranter';
$string['singleforum'] = 'Ett enkelt enskilt diskussionsmne';
$string['startedby'] = 'Pbrjad av:';
$string['subject'] = 'mne';
$string['subscribe'] = 'Prenumerera p detta forum';
$string['subscribeall'] = 'Registrera alla som prenumeranter p detta forum';
$string['subscribed'] = 'Prenumererar';
$string['subscribenone'] = 'Avregistrera alla som prenumeranter p detta forum';
$string['subscribers'] = 'Prenumeranter';
$string['subscribersto'] = 'Prenumerera till \'$a\'';
$string['subscribestart'] = 'Skicka e-postkopior av inlgg i detta forum till mig ';
$string['subscribestop'] = 'Skicka INTE e-postkopior av inlgg i detta forum  till mig ';
$string['subscription'] = 'Prenumeration';
$string['subscriptions'] = 'Prenumerationer';
$string['unsubscribe'] = 'Avbestll prenumeration frn detta forum';
$string['unsubscribed'] = 'Avbestlld';
$string['unsubscribeshort'] = 'Avregistrera prenumeration';
$string['yesforever'] = 'Ja, permanent';
$string['yesinitially'] = 'Ja, till att brja med';
$string['youratedthis'] = 'Du vrderade detta';
$string['yournewtopic'] = 'Ditt nya diskussionsmne';
$string['yourreply'] = 'Ditt svar';

?>

==> moodle-1.5.3-pgsql.tgz: moodle/lang/sv/forum.php <==
<?PHP // $Id$ 
      // forum.php - created with Moodle 1.5 ALPHA (2005042400)


$string['addanewdiscussion'] = 'Lgg till ett nytt diskussionsmne';
$string['addanewtopic'] = 'Lgg till ett nytt mne';
$string['advancedsearch'] = 'Avancerad skning';
$string['allforums'] = 'Alla forum';
$string['allowchoice'] = 'Tillt alla att vlja';
$string['allowdiscussions'] = 'Kan en $a gra inlgg i detta forum?';
$string['allowratings'] = 'Vill Du att det ska vara tilltet att bedma/vrdera inlgg?';
$string['allowsdiscussions'] = 'Detta forum tillter var och en att starta ett diskussionsmne.';
$string['anyfile'] = 'Vilken fil som helst';
$string['attachment'] = 'Bilaga';
$string['bynameondate'] = 'av $a->name - $a->date';
$string['configcleanreadtime'] = 'Tidpunkten under dagen d gamla inlgg ska rensas frn \'ls\'-tabellen.';
$string['configdisplaymode'] = 'Det frinstllda sttet att visa diskussionsmnen, om Du inte har stllt in ett annat.';
$string['configenablerssfeeds'] = 'Den hr omkopplaren aktiverar RSS -inmatning fr alla forum. Du mste dock fortfarande koppla p inmatningen manuellt i instlllningarna fr varje enskilt forum.';
$string['configlongpost'] = 'Alla inlgg som verskrider den hr lngden (frutom HTML) anses vara lnga.';
$string['configmanydiscussions'] = 'Maximalt antal diskussionsmnen som visas per sida i ett forum.';
$string['configmaxbytes'] = 'Standardval (frinstllt vrde) fr den maximala storleken p bifogade filer p den hr webbsajten (det finns ven lokala instllningar fr t.ex. varje enskild kurs)';
$string['configoldpostdays'] = 'Antal dagar d vilket gammalt inlgg som helst ska anses vara lst.';
$string['configreplytouser'] = 'Nr ett inlgg i ett forum har skickats som e-post; ska det d innehlla anvndarens e-postadress s att mottagarna kan svara personligen snarare n via forumet? ven om Du vljer \"Ja\" fr denna instllning s kan anvndaren i sin profil vlja att dlja sin e-postadress.';
$string['configshortpost'] = 'Alla inlgg som verskrider den hr lngden (frutom HTML) anses vara lnga.';
$string['configtrackreadposts'] = 'Stll in detta till \'Ja\' om Du vill spra lst/inte lst fr varje anvndare. ';
$string['configusermarksread'] = 'Om \'Ja\' s mste anvndare manuellt markera ett inlgg som lst. Om \'Nej\' s markeras inlgget som lst nr det visas. ';
$string['couldnotadd'] = 'Det gick inte att lgga till Ditt inlgg p grund av oknt fel.';
$string['couldnotdeleteratings'] = 'Tyvrr, detta kan inte tas bort eftersom folk redan har vrderat det.';
$string['couldnotdeletereplies'] = 'Tyvrr, det kan inte tas bort eftersom folk redan har svarat p det.';
$string['couldnotupdate'] = 'Det gick inte att uppdatera Ditt inlgg p grund av oknt fel.';
$string['delete'] = 'Ta bort';
$string['deleteddiscussion'] = 'Diskussionsmnet har tagits bort';
$string['deletedpost'] = 'Inlgget har tagits bort';
$string['deletedposts'] = 'De inlggen har tagits bort';
$string['deletesure'] = 'r Du sker p att Du vill ta bort detta inlgg?';
$string['deletesureplural'] = 'r Du sker p att Du vill ta bort detta inlgg och alla svar? ($a inlgg)';
$string['digestmailheader'] = 'Det hr r Din dagliga sammanfattning av nya inlgg  i $a->sitename forum. Fr att ndra p Dina val a e-post frn forum - g till $a->userprefs ';
$string['digestmailprefs'] = 'Din anvndarprofil';
$string['digestmailsubject'] = '$a: sammanfattning av forum';
$string['digestsentusers'] = 'Sammanfattande e-postmeddelanden har skickats till $a anvndare.';
$string['discussion'] = 'Diskussionsmne';
$string['discussionmoved'] = 'Den hr diskussionsmnet har flyttats till \'$a\'.';
$string['discussionname'] = 'Namn p diskussion';
$string['discussions'] = 'Diskussionsmnen';
$string['discussionsstartedby'] = '$a  inledde det hr diskussionsmnet';
$string['discussionsstartedbyrecent'] = 'Diskussioner som nyligen har inletts av \'$a\'.';
$string['discussthistopic'] = 'Diskutera detta mne';
$string['eachuserforum'] = 'Var och en  bidrar med ett  diskussionsmne';
$string['edit'] = 'Redigera';
$string['editedby'] = 'Redigerad av  $a->name - $a->date';
$string['editing'] = 'Redigering';
$string['emptymessage'] = 'Ngot var fel med Ditt inlgg.  Kanske skrev Du inte in ngon text, eller s var bilagan fr stor.  Dina ndringar har INTE sparats.';
$string['everyonecanchoose'] = 'Alla kan vlja att prenumerera';
$string['everyoneissubscribed'] = 'Alla prenumererar p detta forum';
$string['existingsubscribers'] = 'Befintliga prenumeranter';
$string['forcesubscribe'] = 'Tvinga alla att prenumerera';
$string['forcesubscribeq'] = 'Tvinga alla att prenumerera?';
$string['forum'] = 'Forum';
$string['forumintro'] = 'Introduktion till forum';
$string['forumname'] = 'Forumets namn';
$string['forumposts'] = 'Inlgg i forum';
$string['forums'] = 'Forum';
$string['forumtype'] = 'Typ av forum';
$string['generalforum'] = 'Standardforum fr allmnt bruk';
$string['generalforums'] = 'Allmnna forum';
$string['inforum'] = 'i $a';
$string['intronews'] = 'Allmnna nyheter och meddelanden';
$string['introsocial'] = 'Ett ppet forum dr Du kan diskutera vad Du vill';
$string['introteacher'] = 'Ett forum endast fr distanslrares anteckningar och diskussionsmnen';
$string['lastpost'] = 'Senaste inlgg';
$string['learningforums'] = 'Forum fr lrande';
$string['markalldread'] = 'Markera alla inlgg i detta diskussionsmne som lsta';
$string['markallread'] = 'Markera alla inlgg i detta forum som lsta';
$string['markread'] = 'Markera som lst';
$string['markreadbutton'] = 'Markera som <br  /> lst';
$string['markunread'] = 'Markera som olst';
$string['markunreadbutton'] = 'Markera <br  />som olst';
$string['maxattachmentsize'] = 'Maximal storlek p bifogad fil';
$string['maxtimehaspassed'] = 'Tyvrr, men maximitiden fr att redigera detta inlgg ($a) har passerat!';
$string['message'] = 'Meddelande';
$string['missingsearchterms'] = 'De fljande sktermerna frekommer bara i HTML-koden fr det hr meddelandet: ';
$string['modeflatnewestfirst'] = 'Visa svarslista, med det senaste frst';
$string['modeflatoldestfirst'] = 'Visa svarslista, med det ldsta frst';
$string['modenested'] = 'Visa svar i nstlad form';
$string['modethreaded'] = 'Visa svar i trdad form';
$string['modulename'] = 'Forum';
$string['modulenameplural'] = 'Forum';
$string['more'] = 'mer';
$string['movethisdiscussionto'] = 'Flytta det hr diskussionsmnet  till...';
$string['namenews'] = 'Nyhetsforum';
$string['namesocial'] = 'Gemenskapsforum';
$string['nameteacher'] = 'Lrarforum';
$string['newforumposts'] = 'Nya inlgg i forum';
$string['nodiscussions'] = 'Det finns nnu inga diskussionsmnen i detta forum';
$string['noguestpost'] = 'Tyvrr, gster har ingen behrighet att gra inlgg hr';
$string['noguestsubscribe'] = 'Gster fr tyvrr inte prenumerera fr att f inlgg i forum skickade med e-post.';
$string['noguesttracking'] = 'Tyvrr, gster fr inte stlla in alternativ fr sprning.';
$string['nomorepostscontaining'] = 'Det gick inte att hitta ngra inlgg som innehller \'$a\' ';
$string['nonews'] = 'Inga nya inlgg nnu';
$string['noposts'] = 'Inga inlgg';
$string['nopostscontaining'] = 'Det gick inte att hitta  ngra inlgg som innehller \'$a\' ';
$string['nosubscribers'] = 'Det finns nnu inga prenumeranter p detta forum';
$string['notingroup'] = 'Du mste tyvrr vara med i en grupp fr att se detta forum.';
$string['notrackforum'] = 'Spra inte olsta meddelanden';
$string['nownotsubscribed'] = '$a->name kommmer INTE f kopior av \'$a->forum\' med e-post.';
$string['nownottracking'] = ' $a->name sprar inte lngre \'$a->forum\'. ';
$string['nowsubscribed'] = '$a->name kommer f kopior av \'$a->forum\' med e-post.';
$string['nowtracking'] = '$a->name sprar nu \'$a->forum\'.';
$string['numposts'] = '$a inlgg';
$string['olderdiscussions'] = 'ldre diskussionsmnen';
$string['oldertopics'] = 'ldre mnen';
$string['openmode0'] = 'Inga diskussionsmnen, inga svar';
$string['openmode1'] = 'Inga diskussionsmnen, men svar r tilltna';
$string['openmode2'] = 'Diskussionsmnen och svar r tilltna';
$string['parent'] = 'Visa \'frldern\' till detta inlgg';
$string['parentofthispost'] = 'Frldern till detta inlgg';
$string['postadded'] = 'Ditt inlgg har lagts till.<p>Du har $a fr att redigera det om Du vill gra ndringar.';
$string['postincontext'] = 'Se detta inlgg i sitt sammanhang';
$string['postmailinfo'] = 'Detta r en kopia p ett meddelande inlagt p $a webbplats.
Fr att lgga till Ditt svar via webbplatsen, klicka p denna lnk:';
$string['postrating1'] = 'Visar mest enskilt,(rationellt) inriktat  vetande (kunskap)';
$string['postrating2'] = 'Enskilt,(rationellt) inriktat  vetande (kunskap) och socialt, (empatiskt) inriktat vetande (kunskap)';
$string['postrating3'] = 'Visar mest socialt, (empatiskt) inriktat vetande (kunskap)';
$string['posts'] = 'Inlgg';
$string['posttoforum'] = 'Publicera inlgget i forumet';
$string['postupdated'] = 'Ditt inlgg har blivit uppdaterat';
$string['potentialsubscribers'] = 'Mjliga prenumeranter';
$string['processingdigest'] = 'Bearbetar sammanfattande e-postmeddelande fr anvndare $a';
$string['processingpost'] = 'Bearbetar inlgg $a';
$string['prune'] = 'Avbryt';
$string['prunedpost'] = 'Ett nytt diskussionsmne har skapats av posten';
$string['pruneheading'] = 'Avbryt inlgg och flytta till ett nytt diskussionsmne';
$string['rate'] = 'Omdme';
$string['rating'] = 'Bedmning/vrdering';
$string['ratingeveryone'] = 'Alla kan bedma/vrdera ett inlgg';
$string['ratingno'] = 'Ingen bedmning/vrdering';
$string['ratingonlyteachers'] = 'Endast $a kan bedma/vrdera inlgg';
$string['ratingpublic'] = '$a kan se allas bedmningar/vrderingar';
$string['ratingpublicnot'] = '$a kan bara se sina egna bedmningar/vrderingar';
$string['ratings'] = 'Bedmning/vrdering';
$string['ratingssaved'] = 'bedmningarna/vrderingarna har blivit  sparade';
$string['ratingsuse'] = 'Anvnd bedmningar/vrderingar ';
$string['ratingtime'] = 'Begrnsa bedmning/vrdering till inlgg med datum i det hr intervallet:';
$string['re'] = 'Svar:';
$string['readtherest'] = 'Ls fortsttningen p detta mne';
$string['replies'] = 'Svar:';
$string['repliesmany'] = '$a svar s lngt';
$string['repliesone'] = '$a svar s lngt';
$string['reply'] = 'Svar';
$string['replyforum'] = 'Svar till forum';
$string['rsssubscriberssdiscussions'] = 'Visa RSS-inmatningen fr  \'$a\' diskussionsmnen';
$string['rsssubscriberssposts'] = 'Visa RSS-inmatningen fr  \'$a\'  inlgg';
$string['search'] = 'Sk';
$string['searchdatefrom'] = 'Inlgget mste vara nyare n s hr';
$string['searchdateto'] = 'Inlgget mste vara ldre n s hr';
$string['searchforumintro'] = 'Var snll och mata in skord i ett eller flera av de fljande textflten:';
$string['searchforums'] = 'Sk forum';
$string['searchfullwords'] = 'De hr orden br st som hela ord';
$string['searchnotwords'] = 'De hr orden br INTE tas med';
$string['searcholderposts'] = 'Sk ldre inlgg...';
$string['searchphrase'] = 'Exakt den hr frasen mste vara med i inlgget';
$string['searchresults'] = 'Skresultat';
$string['searchsubject'] = 'De hr orden br vara med i mnet';
$string['searchuser'] = 'Det hr namnet br matcha frfattarens namn';
$string['searchuserid'] = 'Frfattarens Moodle-ID';
$string['searchwhichforums'] = 'Vlj vilket/vilka forum Du vill ska i';
$string['searchwords'] = 'De hr orden kan frekomma var som helst i inlgget';
$string['seeallposts'] = 'Visa alla inlgg som den hr anvndaren har gjort';
$string['sendinratings'] = 'Snd in mina senaste bedmningar/vrderingar';
$string['showsubscribers'] = 'Visa prenumeranter';
$string['singleforum'] = 'Ett enkelt enskilt diskussionsmne';
$string['startedby'] = 'Pbrjad av:';
$string['subject'] = 'mne';
$string['subscribe'] = 'Prenumerera p detta forum';
$string['subscribeall'] = 'Registrera alla som prenumeranter p detta forum';
$string['subscribed'] = 'Prenumererar';
$string['subscribenone'] = 'Avregistrera alla som prenumeranter p detta forum';
$string['subscribers'] = 'Prenumeranter';
$string['subscribersto'] = 'Prenumerera till \'$a\'';
$string['subscribestart'] = 'Skicka e-postkopior av inlgg i detta forum till mig ';
$string['subscribestop'] = 'Skicka INTE e-postkopior av inlgg i detta forum  till mig ';
$string['subscription'] = 'Prenumeration';
$string['subscriptions'] = 'Prenumerationer';
$string['trackforum'] = 'Spra olsta meddelanden';
$string['tracking'] = 'Spra';
$string['trackingoff'] = 'Av';
$string['trackingon'] = 'P';
$string['trackingoptional'] = 'Valfri';
$string['trackingtype'] = 'Spra lsningen av detta forum?';
$string['unread'] = 'Olst ';
$string['unreadposts'] = 'Olsta inlgg';
$string['unreadpostsnumber'] = '$a olsta inlgg';
$string['unreadpostsone'] = '1 olst inlgg';
$string['unsubscribe'] = 'Avbestll prenumeration frn detta forum';
$string['unsubscribed'] = 'Avbestlld';
$string['unsubscribeshort'] = 'Avregistrera prenumeration';
$string['yesforever'] = 'Ja, permanent';
$string['yesinitially'] = 'Ja, till att brja med';
$string['youratedthis'] = 'Du vrderade detta';
$string['yournewtopic'] = 'Ditt nya diskussionsmne';
$string['yourreply'] = 'Ditt svar';

?>
